@@ -133,6 +133,12 @@ declare_rs <- function(N = NULL,
                 rs_probabilities(return_object),
                 assign.env = return_object)
   
+  
+  delayedAssign("probabilities_matrix",
+                cbind((1 - rs_probabilities(return_object)),
+                      rs_probabilities(return_object)),
+                assign.env = return_object)
+  
   class(return_object) <-
     c("rs_declaration",  paste0("rs_", rs_type))
   attr(return_object, "call") <- match.call()
